Documentation
¶
Overview ¶
Package classes can be inherited by components to provide the ability to set custom classes on the component.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Classes ¶
type Classes struct {
// contains filtered or unexported fields
}
Classes holds custom classes for a component.
func (*Classes) AddClasses ¶
AddClasses will add the given class to the list of classes.
func (*Classes) HasClasses ¶
HasClasses returns a boolean indicating whether any classes have been set.
Click to show internal directories.
Click to hide internal directories.